svn commit: r338230 - user/cperciva/portsnap-build/s
Xin LI
delphij at FreeBSD.org
Thu Aug 23 02:21:42 UTC 2018
Author: delphij
Date: Thu Aug 23 02:21:40 2018
New Revision: 338230
URL: https://svnweb.freebsd.org/changeset/base/338230
Log:
Pass UNAME_r to describes-run.sh.
Modified:
user/cperciva/portsnap-build/s/describes-run.sh
user/cperciva/portsnap-build/s/treesnap-build.sh
Modified: user/cperciva/portsnap-build/s/describes-run.sh
==============================================================================
--- user/cperciva/portsnap-build/s/treesnap-build.sh Thu Aug 23 02:20:09 2018 (r338229)
+++ user/cperciva/portsnap-build/s/treesnap-build.sh Thu Aug 23 02:21:40 2018 (r338230)
@@ -36,14 +36,15 @@ sh -e s/treesnap-mktars-all.sh ${PORTSDIR} ${SNAP} ${S
# Unmount the ports tree
while ! umount /dev/md${PORTSMD}; do
- sleep 1
+ sleep 1;
done
# Perform index describes
for N in ${DESCRIBES}; do
echo "`date`: Starting describe run for ${N}.x"
if ! sh -e s/describes-run.sh /dev/md${PORTSMD} $WORLDTAR $JAILDIR \
- ${N}99999 ${SNAP}/DESCRIBE.${N} 2>${SNAP}/DESCRIBE.${N}.err; then
+ ${N}99999 ${SNAP}/DESCRIBE.${N} ${N}.x-STABLE \
+ 2>${SNAP}/DESCRIBE.${N}.err; then
echo "`date`: ${N}.x describes failed"
cat ${SNAP}/DESCRIBE.${N}.err
rm ${SNAP}/DESCRIBE.${N}
More information about the svn-src-user
mailing list
--- user/cperciva/portsnap-build/s/describes-run.sh Thu Aug 23 02:20:09 2018 (r338229)
+++ user/cperciva/portsnap-build/s/describes-run.sh Thu Aug 23 02:21:40 2018 (r338230)
@@ -6,12 +6,13 @@ if [ -z "$PORTSNAP_BUILD_CONF_READ" ]; then
exit 1
fi
# usage: sh -e describes-run.sh PORTSDISK WORLDTAR JAILDIR OSVERSION DESCFILE
PORTSDISK="$1"
WORLDTAR="$2"
JAILDIR="$3"
OSVERSION="$4"
DESCFILE="$5"
+UNAMER="$6"
# helper function
findruleset () {
@@ -62,6 +63,7 @@ if env - PATH=${PATH} jail -c path=${JAILDIR} host.hos
> ${DESCFILE} <<- EOF
export __MAKE_CONF=/nonexistant
export OSVERSION=${OSVERSION}
+ export UNAME_r=${UNAMER}
export PORTOBJFORMAT=elf
export INDEX_TMPDIR=/tmp
export WRKDIRPREFIX=/tmp
@@ -82,16 +84,16 @@ fi
# Clean up
while ! umount ${JAILDIR}/dev; do
- sleep 1
+ sleep 1;
done
while ! umount ${JAILDIR}/tmp; do
- sleep 1
+ sleep 1;
done
while ! umount ${JAILDIR}/usr/ports; do
- sleep 1
+ sleep 1;
done
while ! umount ${JAILDIR}; do
- sleep 1
+ sleep 1;
done
mdconfig -d -u ${JAILMD}
mdconfig -d -u ${TMPMD}
@@ -6,12 +6,13 @@ if [ -z "$PORTSNAP_BUILD_CONF_READ" ]; then
exit 1
fi
-# usage: sh -e describes-run.sh PORTSDISK WORLDTAR JAILDIR OSVERSION DESCFILE
+# usage: sh -e describes-run.sh PORTSDISK WORLDTAR JAILDIR OSVERSION DESCFILE UNAMER
PORTSDISK="$1"
WORLDTAR="$2"
Modified: user/cperciva/portsnap-build/s/treesnap-build.sh
==============================================================================